@@ -28,12 +28,11 @@ from __future__ import annotations
 
 __title__ = "asyncnt"
 __author__ = "axemalt"
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 
 
 from typing import Optional, Type, List, Dict
 from types import TracebackType
-import cloudscraper
 import asyncio
 import aiohttp
 import json
@@ -66,11 +65,12 @@ class InvalidTeamTag(AsyncNTException):
 class HTTPException(AsyncNTException):
     """Exception that is raised when an HTTP request operation fails."""
 
+    __slots__ = ["response", "status", "code"]
+
     def __init__(self, response: aiohttp.ClientResponse):
         self.response = response
         self.status: int = response.status
-        self.code: int
-        self.code = 0
+        self.code: int = 0
 
         fmt = "{0.status} {0.reason} (error code: {1})"
 
@@ -80,6 +80,8 @@ class HTTPException(AsyncNTException):
 class Car:
     """Represents a Nitro Type car."""
 
+    __slots__ = ["id", "hue_angle", "url"]
+
     def __init__(self, data):
         #: The car's id.
         self.id: int = data[0]
@@ -97,6 +99,8 @@ class Car:
 class Loot:
     """Represents a Nitro Type loot."""
 
+    __slots__ = ["id", "type", "name", "rarity"]
+
     def __init__(self, data):
         #: The loot's ID.
         self.id: int = data["lootID"]
@@ -111,6 +115,33 @@ class Loot:
 class Racer:
     """Represents a Nitro Type racer."""
 
+    __slots__ = [
+        "id",
+        "username",
+        "display_name",
+        "membership",
+        "level",
+        "experience",
+        "profile_views",
+        "nitros",
+        "nitros_used",
+        "nitros_total",
+        "races",
+        "team_tag",
+        "average_speed",
+        "high_speed",
+        "friend_reqs_allowed",
+        "looking_for_team",
+        "created",
+        "car",
+        "cars",
+        "cars_owned",
+        "cars_sold",
+        "cars_total",
+        "loot",
+        "_scraper",
+    ]
+
     def __init__(self, data: Dict, *, scraper: Session) -> None:
         self._scraper = scraper
 
@@ -197,6 +228,36 @@ class Racer:
 class Team:
     """Represents a Nitro Type Team."""
 
+    __slots__ = [
+        "id",
+        "tag",
+        "name",
+        "open",
+        "created",
+        "profile_views",
+        "member_count",
+        "min_level",
+        "min_races",
+        "min_speed",
+        "description",
+        "daily_speed",
+        "daily_accuracy",
+        "daily_points",
+        "daily_races",
+        "season_speed",
+        "season_accuracy",
+        "season_points",
+        "season_races",
+        "all_time_speed",
+        "all_time_accuracy",
+        "all_time_races",
+        "all_time_points",
+        "_scraper",
+        "_captain_username",
+        "_leader_usernames",
+        "_member_usernames"
+    ]
+
     def __init__(self, data: Dict, *, scraper: Session) -> None:
         self._scraper = scraper
 
@@ -332,24 +393,40 @@ class Team:
         return await asyncio.gather(*coruntines)
 
 
-class Session(cloudscraper.CloudScraper):
+class Session:
     """First-class interface for making HTTP requests to Nitro Type."""
 
-    __slots__ = ["_session", "headers"]
+    __slots__ = [
+        "per",
+        "rate",
+        "cache_for",
+        "_lock",
+        "_loop",
+        "_cache",
+        "_window",
+        "_tokens",
+        "_headers",
+        "_session",
+    ]
 
     def __init__(self) -> None:
-        super().__init__()
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/36.0.1941.0 Safari/537.36",
+            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
+            "Accept-Language": "en-US,en;q=0.9",
+            "Accept-Encoding": "gzip, deflate"
+        }
 
         self.per: float = 1
         self.rate: int = 10
         self.cache_for = 300
+
         self._lock: asyncio.Lock = asyncio.Lock()
         self._loop = asyncio.get_event_loop()
         self._cache: Dict[str, aiohttp.ClientResponse] = {}
         self._window: float = 0.0
         self._tokens: int = self.rate
-        self._session: aiohttp.ClientSession = aiohttp.ClientSession()
-        self._semaphore: asyncio.Semaphore = asyncio.Semaphore(value=self.rate)
+        self._session: aiohttp.ClientSession = aiohttp.ClientSession(headers=headers)
 
     def __del__(self) -> None:
         if not self._session.closed:
@@ -393,8 +470,8 @@ class Session(cloudscraper.CloudScraper):
         :return: The data from the url.
         :rtype: Optional[aiohttp.ClientResponse]
         """
-        
-        if (result := self._cache.get(url)):
+
+        if result := self._cache.get(url):
             return result
 
         async with self._lock:
@@ -402,11 +479,8 @@ class Session(cloudscraper.CloudScraper):
             if wait_for:
                 await asyncio.sleep(wait_for)
                 self._update_rate_limit()
-        
-        async with self._semaphore:
-            response: aiohttp.ClientResponse = await self._session.get(
-                url, headers=self.headers
-            )
+
+        response: aiohttp.ClientResponse = await self._session.get(url)
 
         if response.status == 200:
             self._cache[url] = response
@@ -415,7 +489,6 @@ class Session(cloudscraper.CloudScraper):
         else:
             raise HTTPException(response)
 
-
     async def get_racer(self, username: str) -> Optional[Racer]:
         """
         Get a racer with a username.
